# *MGEfinder* - A toolbox for identifying mobile genetic element (MGE) insertions from short-read sequencing data of bacterial isolates.

The command-line tool *MGEfinder* identifies large insertions and genotypes them with respect to a reference genome.

It is designed to work with haploid genomes, and has been tested extensively on bacteria.

It can identify mobile genetic elements and their sites of insertion using an *ab initio* approach.

Follow the links below to learn more.

## Table of Contents
1. [How it works](docs/howitworks.md)  
2. [Install or update software](docs/install.md)  
3. [Step-by-step tutorial](docs/tutorial.md)
4. [Detailed user manual](docs/manual.md)


## Preprint
Durrant, Matthew, Michelle M. Li, Benjamin Siranosian, and Ami S. Bhatt. 2019. ["Mobile Genetic Element Insertions Drive 
Antibiotic Resistance across Pathogens.](https://doi.org/10.1101/527788) *bioRxiv*.

## Questions / Comments
Please submit any questions or comments to our [issues handler](https://github.com/durrantmm/mgefinder/issues). 
